Name:           jline2
Version:        2.14.6
Release:        %mkrel 8
Group:          Development/Java
Summary:        Java library for handling console input
License:        BSD
URL:            https://jline.github.io/jline2/

Source0:        https://github.com/jline/jline2/archive/jline-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.easymock:easymock)
BuildRequires:  mvn(org.fusesource.jansi:jansi:1)

%description
JLine is a Java library for handling console input.  It is similar in
functionality to BSD editline and GNU readline.  People familiar with
the readline/editline capabilities for modern shells (such as bash and
tcsh) will find most of the command editing features of JLine to be
familiar.

%{?javadoc_package}

%prep
%autosetup -n jline2-jline-%{version}

# remove unnecessary dependency on parent POM
%pom_remove_parent

# Remove maven-shade-plugin usage
%pom_remove_plugin "org.apache.maven.plugins:maven-shade-plugin"
# Remove animal sniffer plugin in order to reduce deps
%pom_remove_plugin "org.codehaus.mojo:animal-sniffer-maven-plugin"

# Remove unavailable and unneeded deps
%pom_xpath_remove "pom:build/pom:extensions"
%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :maven-javadoc-plugin

# Makes the build fail on deprecation warnings from jansi
%pom_xpath_remove 'pom:arg[text()="-Werror"]'

# Do not import non-existing internal package
%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId = 'maven-bundle-plugin']/pom:executions/pom:execution/pom:configuration/pom:instructions/pom:Import-Package"
%pom_xpath_inject "pom:build/pom:plugins/pom:plugin[pom:artifactId = 'maven-bundle-plugin']/pom:executions/pom:execution/pom:configuration/pom:instructions" "<Import-Package>javax.swing;resolution:=optional,org.fusesource.jansi,!org.fusesource.jansi.internal</Import-Package>"

# Be sure to export jline.internal, but not org.fusesource.jansi.
# See https://bugzilla.redhat.com/show_bug.cgi?id=1317551
%pom_xpath_set "pom:build/pom:plugins/pom:plugin[pom:artifactId = 'maven-bundle-plugin']/pom:executions/pom:execution/pom:configuration/pom:instructions/pom:Export-Package" "jline.*;-noimport:=true"

# Update required version of jansi 1.x
%pom_xpath_set //pom:jansi.version 1.18

# drop a nondeterministic test
find -name TerminalFactoryTest.java -delete
# it's also the only test that uses powermock, so drop the powermock dependency
%pom_remove_dep org.powermock:

# Fix javadoc generation on java 11
%pom_xpath_inject pom:build/pom:plugins "<plugin>
<artifactId>maven-javadoc-plugin</artifactId>
<configuration><source>1.8</source></configuration>
</plugin>"

# (daviddavid) this test fails
find . -name "ConsoleReaderTest.java" -delete

%build
%mvn_build -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files -f .mfiles
%doc CHANGELOG.md README.md
%license LICENSE.txt




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 2.14.6-8.mga10
+ Revision: 2223436
- Mageia 10 Mass Rebuild

* Fri May 24 2024 ns80 <ns80> 2.14.6-7.mga10
+ Revision: 2067202
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 2.14.6-6.mga9
+ Revision: 1827754
- Mageia 9 Mass Rebuild

* Tue Apr 06 2021 wally <wally> 2.14.6-5.mga9
+ Revision: 1713884
- increase release to be higher than obsoletes in mga8 jline pkg (mga#28728)
- drop technically unneeded conflicts added in r1713812

* Tue Apr 06 2021 daviddavid <daviddavid> 2.14.6-2.mga9
+ Revision: 1713812
- add conflict to ease upgrade mga8 -> mga9

* Sun Feb 28 2021 daviddavid <daviddavid> 2.14.6-1.mga9
+ Revision: 1694473
- Unretire jline2 due to introduction of jline 3.x
+ danf <danf>
- Switch URLs from http: to https:

* Wed Oct 15 2014 umeabot <umeabot> 2.10-4.mga5
+ Revision: 750535
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 2.10-2.mga4
+ Revision: 545489
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 2.10-1.mga4
+ Revision: 501305
- New version

* Sat Jan 12 2013 umeabot <umeabot> 2.5-3.mga3
+ Revision: 355483
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 22 2011 gil <gil> 2.5-2.mga2
+ Revision: 171093
- build fixes
  jline.console.ConsoleReader.back should be protected instead of private
- imported package jline2
+ dmorgan <dmorgan>
- Clean spec file to mageia guidelines


* Tue May 31 2011 Marek Goldmann <mgoldman@redhat.com> 2.5-1
- Initial packaging


